@@ -5,19 +5,19 @@
     SPDX-License-Identifier: GPL-2.0-only
 */
 
+#include <QFile>
 #include <QObject>
 #include <QStandardPaths>
-#include <QFile>
 #include <QTemporaryDir>
 
-#include <kfileplacesview.h>
-#include <kfileplacesmodel.h>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KProtocolInfo>
+#include <kfileplacesmodel.h>
+#include <kfileplacesview.h>
 
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 
 static QString bookmarksFile()
 {
@@ -34,6 +34,7 @@ private Q_SLOTS:
 
     void testUrlChanged_data();
     void testUrlChanged();
+
 private:
     QTemporaryDir m_tmpHome;
 };
@@ -42,14 +43,13 @@ void KFilePlacesViewTest::initTestCase()
 {
     QVERIFY(m_tmpHome.isValid());
     qputenv("HOME", m_tmpHome.path().toUtf8());
-    qputenv("KDE_FORK_SLAVES", "yes"); // to avoid a runtime dependency on klauncher
     qputenv("KDE_FULL_SESSION", "1"); // attempt to enable recentlyused:/ if present, so we only need to test for isKnownProtocol below
     QStandardPaths::setTestModeEnabled(true);
 
     cleanupTestCase();
 
     KConfig config(QStringLiteral("baloofilerc"));
-    KConfigGroup basicSettings = config.group("Basic Settings");
+    KConfigGroup basicSettings = config.group(QStringLiteral("Basic Settings"));
     basicSettings.writeEntry("Indexing-Enabled", true);
     config.sync();
 
@@ -81,12 +81,6 @@ void KFilePlacesViewTest::testUrlChanged_data()
         QTest::newRow("Modified Today") << idx++ << QStringLiteral("timeline:/today");
         ++idx; // Modified Yesterday gets turned into "timeline:/2020-06/2020-06-05"
     }
-
-    // search
-    QTest::newRow("Documents") << idx++ << QStringLiteral("baloosearch:/documents");
-    QTest::newRow("Images") << idx++ << QStringLiteral("baloosearch:/images");
-    QTest::newRow("Audio Files") << idx++ << QStringLiteral("baloosearch:/audio");
-    QTest::newRow("Videos") << idx++ << QStringLiteral("baloosearch:/videos");
 }
 
 void KFilePlacesViewTest::testUrlChanged()
