@@ -67,6 +67,7 @@ public:
         , m_delayedMimeTypes(delayedMimeTypes)
         , m_useIconNameCache(false)
         , m_hidden(Auto)
+        , m_hiddenCache(HiddenUncached)
         , m_slow(SlowUnknown)
         , m_bSkipMimeTypeFromContent(mimeTypeDetermination == KFileItem::SkipMimeTypeFromContent)
         , m_bInitCalled(false)
@@ -182,6 +183,7 @@ public:
 
     // Auto: check leading dot.
     enum { Auto, Hidden, Shown } m_hidden : 3;
+    mutable enum { HiddenUncached, HiddenCached, ShownCached } m_hiddenCache : 3;
 
     // Slow? (nfs/smb/ssh)
     mutable enum { SlowUnknown, Fast, Slow } m_slow : 3;
@@ -324,6 +326,7 @@ void KFileItemPrivate::readUDSEntry(bool _urlIsDirectory)
 
     const int hiddenVal = m_entry.numberValue(KIO::UDSEntry::UDS_HIDDEN, -1);
     m_hidden = hiddenVal == 1 ? Hidden : (hiddenVal == 0 ? Shown : Auto);
+    m_hiddenCache = HiddenUncached;
 
     if (_urlIsDirectory && !UDS_URL_seen && !m_strName.isEmpty() && m_strName != QLatin1String(".")) {
         auto path = m_url.path();
@@ -335,6 +338,11 @@ void KFileItemPrivate::readUDSEntry(bool _urlIsDirectory)
     }
 
     m_iconName.clear();
+
+    // If filemode is not unknown, set fileItem to initialised
+    if (m_fileMode != KFileItem::Unknown) {
+        m_bInitCalled = true;
+    }
 }
 
 // Inlined because it is used only in one place
@@ -634,6 +642,7 @@ void KFileItem::refresh()
     d->m_fileMode = KFileItem::Unknown;
     d->m_permissions = KFileItem::Unknown;
     d->m_hidden = KFileItemPrivate::Auto;
+    d->m_hiddenCache = KFileItemPrivate::HiddenUncached;
     refreshMimeType();
 
 #if HAVE_POSIX_ACL
@@ -705,6 +714,7 @@ void KFileItem::setName(const QString &name)
     if (d->m_entry.contains(KIO::UDSEntry::UDS_NAME)) {
         d->m_entry.replace(KIO::UDSEntry::UDS_NAME, d->m_strName); // #195385
     }
+    d->m_hiddenCache = KFileItemPrivate::HiddenUncached;
 }
 
 QString KFileItem::linkDest() const
@@ -723,8 +733,45 @@ QString KFileItem::linkDest() const
 
     // If not in the KIO::UDSEntry, or if UDSEntry empty, use readlink() [if local URL]
     if (d->m_bIsLocalUrl) {
+        // Use QFileInfo::readSymlink once we depend on Qt 6.6+
+#ifdef Q_OS_UNIX
+        // Use readlink on Unix because symLinkTarget turns relative targets into absolute (#456198)
+        // implementation following file_unix.cpp readlinkToBuffer()
+#if HAVE_STATX
+        using SizeType = size_t;
+#else
+        using SizeType = off_t;
+#endif
+        SizeType linkSize = size();
+        const QString path = d->m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
+        if (linkSize > SIZE_MAX) {
+            qCWarning(KIO_CORE) << "file size bigger than SIZE_MAX, too big for readlink use!" << path;
+            return {};
+        }
+        SizeType lowerBound = 256;
+        SizeType higherBound = 1024;
+        SizeType bufferSize = qBound(lowerBound, linkSize + 1, higherBound);
+        QByteArray linkTargetBuffer(bufferSize, Qt::Initialization::Uninitialized);
+        const QByteArray pathBA = QFile::encodeName(path);
+        while (true) {
+            ssize_t n = readlink(pathBA.constData(), linkTargetBuffer.data(), linkTargetBuffer.size());
+            if (n < 0 && errno != ERANGE) {
+                qCWarning(KIO_CORE) << "readlink failed!" << pathBA;
+                return {};
+            } else if (n > 0 && static_cast<SizeType>(n) != bufferSize) {
+                // the buffer was not filled in the last iteration
+                // we are finished reading, break the loop
+                linkTargetBuffer.truncate(n);
+                break;
+            }
+            linkTargetBuffer.resize(linkTargetBuffer.size() * 2);
+        }
+        return QString::fromUtf8(linkTargetBuffer);
+#else
         return QFile::symLinkTarget(d->m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile());
+#endif
     }
+
     return QString();
 }
 
@@ -1336,13 +1383,19 @@ bool KFileItem::isHidden() const
     if (d->m_hidden != KFileItemPrivate::Auto) {
         return d->m_hidden == KFileItemPrivate::Hidden;
     }
+    if (d->m_hiddenCache != KFileItemPrivate::HiddenUncached) {
+        return d->m_hiddenCache == KFileItemPrivate::HiddenCached;
+    }
 
     // Prefer the filename that is part of the URL, in case the display name is different.
     QString fileName = d->m_url.fileName();
     if (fileName.isEmpty()) { // e.g. "trash:/"
         fileName = d->m_strName;
     }
-    return fileName.length() > 1 && fileName[0] == QLatin1Char('.'); // Just "." is current directory, not hidden.
+
+    // Just "." is current directory, not hidden.
+    d->m_hiddenCache = fileName.length() > 1 && fileName[0] == QLatin1Char('.') ? KFileItemPrivate::HiddenCached : KFileItemPrivate::ShownCached;
+    return d->m_hiddenCache == KFileItemPrivate::HiddenCached;
 }
 
 void KFileItem::setHidden()
@@ -1414,7 +1467,15 @@ QString KFileItem::getStatusBarInfo() const
     if (d->m_bLink) {
         auto linkText = linkDest();
         if (!linkText.startsWith(QStringLiteral("anon_inode:"))) {
-            linkText = toDisplayUrl(d->m_url.resolved(QUrl(linkText)));
+            auto url = QUrl(linkText).adjusted(QUrl::StripTrailingSlash);
+            if (d->m_url.isLocalFile()) {
+                if (url.scheme().isEmpty()) {
+                    url.setScheme(QStringLiteral("file"));
+                }
+            } else {
+                url = d->m_url.resolved(url);
+            }
+            linkText = toDisplayUrl(url);
         }
         text += QLatin1Char(' ');
         if (comment.isEmpty()) {
