@@ -48,7 +48,10 @@ public:
 RestoreJob::RestoreJob(RestoreJobPrivate &dd)
     : Job(dd)
 {
-    QTimer::singleShot(0, this, SLOT(slotStart()));
+    Q_D(RestoreJob);
+    QTimer::singleShot(0, this, [d]() {
+        d->slotStart();
+    });
 }
 
 RestoreJob::~RestoreJob()
@@ -72,7 +75,7 @@ void RestoreJobPrivate::slotStart()
         q->addSubjob(job);
         q->setProcessedAmount(KJob::Files, q->processedAmount(KJob::Files) + 1);
     } else {
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
         org::kde::KDirNotify::emitFilesRemoved(m_urls);
 #endif
         q->emitResult();
