@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2013 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2013 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_SIMPLEJOB_H
@@ -26,7 +14,6 @@
 
 namespace KIO
 {
-
 class SimpleJobPrivate;
 /**
  * @class KIO::SimpleJob simplejob.h <KIO/SimpleJob>
@@ -41,26 +28,26 @@ class KIOCORE_EXPORT SimpleJob : public KIO::Job
     Q_OBJECT
 
 public:
-    ~SimpleJob() Q_DECL_OVERRIDE;
+    ~SimpleJob() override;
 
 protected:
     /**
      * Suspend this job
      * @see resume
      */
-    bool doSuspend() Q_DECL_OVERRIDE;
+    bool doSuspend() override;
 
     /**
      * Resume this job
      * @see suspend
      */
-    bool doResume() Q_DECL_OVERRIDE;
+    bool doResume() override;
 
     /**
      * Abort job.
      * This kills all subjobs and deletes the job.
      */
-    bool doKill() Q_DECL_OVERRIDE;
+    bool doKill() override;
 
 public:
     /**
@@ -71,19 +58,18 @@ public:
 
     /**
      * Abort job.
-     * Suspends slave to be reused by another job for the same request.
+     * Suspends worker to be reused by another job for the same request.
      */
     virtual void putOnHold();
 
     /**
-     * Discard suspended slave.
+     * Discard suspended worker.
      */
     static void removeOnHold();
 
     /**
      * Returns true when redirections are handled internally, the default.
      *
-     * @since 4.4
      */
     bool isRedirectionHandlingEnabled() const;
 
@@ -93,55 +79,45 @@ public:
      * When this flag is set, redirection requests are simply forwarded to the
      * caller instead of being handled internally.
      *
-     * @since 4.4
      */
     void setRedirectionHandlingEnabled(bool handle);
 
 public Q_SLOTS:
     /**
      * @internal
-     * Called on a slave's error.
+     * Called on a worker's error.
      * Made public for the scheduler.
      */
     void slotError(int, const QString &);
 
 protected Q_SLOTS:
     /**
-     * Called when the slave marks the job
+     * Called when the worker marks the job
      * as finished.
      */
     virtual void slotFinished();
 
     /**
      * @internal
-     * Called on a slave's warning.
+     * Called on a worker's warning.
      */
     virtual void slotWarning(const QString &);
 
     /**
-     * MetaData from the slave is received.
+     * MetaData from the worker is received.
      * @param _metaData the meta data
      * @see metaData()
      */
     virtual void slotMetaData(const KIO::MetaData &_metaData);
 
 protected:
-    /**
-     * Allow jobs that inherit SimpleJob and are aware
-     * of redirections to store the SSL session used.
-     * Retrieval is handled by SimpleJob::start
-     * @param m_redirectionURL Reference to redirection URL,
-     * used instead of m_url if not empty
-     */
-    void storeSSLSessionFromJob(const QUrl &m_redirectionURL);
-
     /**
      * Creates a new simple job. You don't need to use this constructor,
      * unless you create a new job that inherits from SimpleJob.
      */
-    SimpleJob(SimpleJobPrivate &dd);
-private:
+    KIOCORE_NO_EXPORT explicit SimpleJob(SimpleJobPrivate &dd);
 
+private:
     Q_DECLARE_PRIVATE(SimpleJob)
 };
 
@@ -203,7 +179,7 @@ KIOCORE_EXPORT SimpleJob *rename(const QUrl &src, const QUrl &dest, JobFlags fla
 /**
  * Create or move a symlink.
  * This is the lowlevel operation, similar to file_copy and file_move.
- * It doesn't do any check (other than those the slave does)
+ * It doesn't do any check (other than those the worker does)
  * and it doesn't show rename and skip dialogs - use KIO::link for that.
  * @param target The string that will become the "target" of the link (can be relative)
  * @param dest The symlink to create.
@@ -213,14 +189,14 @@ KIOCORE_EXPORT SimpleJob *rename(const QUrl &src, const QUrl &dest, JobFlags fla
 KIOCORE_EXPORT SimpleJob *symlink(const QString &target, const QUrl &dest, JobFlags flags = DefaultFlags);
 
 /**
- * Execute any command that is specific to one slave (protocol).
+ * Execute any command that is specific to one worker (protocol).
  *
  * Examples are : HTTP POST, mount and unmount (kio_file)
  *
- * @param url The URL isn't passed to the slave, but is used to know
- *        which slave to send it to :-)
+ * @param url The URL isn't passed to the worker, but is used to know
+ *        which worker to send it to :-)
  * @param data Packed data.  The meaning is completely dependent on the
- *        slave, but usually starts with an int for the command number.
+ *        worker, but usually starts with an int for the command number.
  * @param flags Can be HideProgressInfo here
  * @return the job handling the operation.
  */
