@@ -170,6 +170,47 @@ static bool isOnCifsMount(const QString &filePath)
     return mount->mountType() == QStringLiteral("cifs") || mount->mountType() == QStringLiteral("smb3");
 }
 
+#if HAVE_STATX
+// statx syscall is available
+using SizeType = size_t;
+using StatStruct = struct statx;
+#else
+using SizeType = off_t;
+using StatStruct = QT_STATBUF;
+#endif
+
+static QByteArray readlinkToBuffer(const StatStruct &buf, const QByteArray &path)
+{
+    // Use readlink on Unix because symLinkTarget turns relative targets into absolute (#352927)
+    SizeType size = stat_size(buf);
+    if (size > SIZE_MAX) {
+        qCWarning(KIO_FILE) << "file size bigger than SIZE_MAX, too big for readlink use!" << path;
+        return {};
+    }
+    SizeType lowerBound = 256;
+    SizeType higherBound = 1024;
+    SizeType bufferSize = qBound(lowerBound, size + 1, higherBound);
+    QByteArray linkTargetBuffer(bufferSize, Qt::Initialization::Uninitialized);
+    while (true) {
+        ssize_t n = readlink(path.constData(), linkTargetBuffer.data(), bufferSize);
+        if (n < 0 && errno != ERANGE) {
+            /* On AIX 5L v5.3 and HP-UX 11i v2 04/09, readlink returns -1
+               with errno == ERANGE if the buffer is too small.
+               According to gnulib/lib/areadlink-with-size.c */
+            qCWarning(KIO_FILE) << "readlink failed!" << path;
+            return {};
+        } else if (n > 0 && static_cast<SizeType>(n) != bufferSize) {
+            // the buffer was not filled in the last iteration
+            // we are finished reading, break the loop
+            linkTargetBuffer.truncate(n);
+            break;
+        }
+        bufferSize *= 2;
+        linkTargetBuffer.resize(bufferSize);
+    }
+    return linkTargetBuffer;
+}
+
 static bool createUDSEntry(const QString &filename, const QByteArray &path, UDSEntry &entry, KIO::StatDetails details, const QString &fullPath)
 {
     assert(entry.count() == 0); // by contract :-)
@@ -209,50 +250,16 @@ static bool createUDSEntry(const QString &filename, const QByteArray &path, UDSE
     QByteArray targetPath = path;
 #endif
 
-#if HAVE_STATX
-    // statx syscall is available
-    struct statx buff;
-#else
-    QT_STATBUF buff;
-#endif
+    StatStruct buff;
 
-    if (LSTAT(path.data(), &buff, details) == 0) {
+    if (LSTAT(path.constData(), &buff, details) == 0) {
         if (Utils::isLinkMask(stat_mode(buff))) {
             QByteArray linkTargetBuffer;
             if (details & (KIO::StatBasic | KIO::StatResolveSymlink)) {
-// Use readlink on Unix because symLinkTarget turns relative targets into absolute (#352927)
-#if HAVE_STATX
-                size_t lowerBound = 256;
-                size_t higherBound = 1024;
-                uint64_t s = stat_size(buff);
-                if (s > SIZE_MAX) {
-                    qCWarning(KIO_FILE) << "file size bigger than SIZE_MAX, too big for readlink use!" << path;
+                linkTargetBuffer = readlinkToBuffer(buff, path);
+                if (linkTargetBuffer.isEmpty()) {
                     return false;
                 }
-                size_t size = static_cast<size_t>(s);
-                using SizeType = size_t;
-#else
-                off_t lowerBound = 256;
-                off_t higherBound = 1024;
-                off_t size = stat_size(buff);
-                using SizeType = off_t;
-#endif
-                SizeType bufferSize = qBound(lowerBound, size + 1, higherBound);
-                linkTargetBuffer.resize(bufferSize);
-                while (true) {
-                    ssize_t n = readlink(path.constData(), linkTargetBuffer.data(), bufferSize);
-                    if (n < 0 && errno != ERANGE) {
-                        qCWarning(KIO_FILE) << "readlink failed!" << path;
-                        return false;
-                    } else if (n > 0 && static_cast<SizeType>(n) != bufferSize) {
-                        // the buffer was not filled in the last iteration
-                        // we are finished reading, break the loop
-                        linkTargetBuffer.truncate(n);
-                        break;
-                    }
-                    bufferSize *= 2;
-                    linkTargetBuffer.resize(bufferSize);
-                }
                 const QString linkTarget = QFile::decodeName(linkTargetBuffer);
                 entry.fastInsert(KIO::UDSEntry::UDS_LINK_DEST, linkTarget);
             }
